@@ -3,6 +3,16 @@
 #include <iostream>
 #include <ostream>
 
+#include <octave/octave-config.h>
+#ifdef OCTAVE_EXPORT
+  #undef OCTAVE_EXPORT
+  #define OCTAVE_EXPORT
+#endif
+#ifdef OCTAVE_IMPORT
+  #undef OCTAVE_IMPORT
+  #define OCTAVE_IMPORT
+#endif
+
 #include <octave/builtin-defun-decls.h>
 #include <octave/dir-ops.h>
 #include <octave/file-ops.h>
@@ -600,6 +610,12 @@ namespace coder_compiler
       std::function<void ()> m_fcn;
     };
 
+#if OCTAVE_MAJOR_VERSION < 10
+    std::string stdflag = "-std=gnu++11";
+#else
+    std::string stdflag = "-std=gnu++17";
+#endif
+
     auto init = [&]()
     {
       std::string filename = "coder";
@@ -651,7 +667,7 @@ namespace coder_compiler
           call_mkoctfile (
             ovl(
             octave_value( quote("-o " + obj)),
-            octave_value(quote("-std=gnu++11")),
+            octave_value(quote(stdflag)),
             octave_value("-fPIC"),
             octave_value("-c"),
             octave_value(dbg),
@@ -698,7 +714,7 @@ namespace coder_compiler
           call_mkoctfile (
             ovl(
             octave_value( quote("-o " + obj)),
-            octave_value(quote("-std=gnu++11")),
+            octave_value(quote(stdflag)),
             octave_value("-fPIC"),
             octave_value("-c"),
             octave_value(dbg),
@@ -734,7 +750,7 @@ namespace coder_compiler
           call_mkoctfile (
             ovl(
             octave_value( quote("-o " + tmpobj)),
-            octave_value(quote("-std=gnu++11")),
+            octave_value(quote(stdflag)),
             octave_value("-fPIC"),
             octave_value("-c"),
             octave_value(dbg),
@@ -861,7 +877,7 @@ namespace coder_compiler
       call_mkoctfile (
         ovl(
         octave_value( quote("-o " + obj)),
-        octave_value(quote("-std=gnu++11")),
+        octave_value(quote(stdflag)),
         octave_value("-fPIC"),
         octave_value("-c"),
         octave_value(dbg),
@@ -931,7 +947,7 @@ namespace coder_compiler
           call_mkoctfile (
             ovl(
             octave_value( quote("-o " + obj)),
-            octave_value(quote("-std=gnu++11")),
+            octave_value(quote(stdflag)),
             octave_value("-fPIC"),
             octave_value("-c"),
             octave_value(dbg),
@@ -993,7 +1009,7 @@ namespace coder_compiler
             octave_value("-o"),
             octave_value(quote(obj)),
             octave_value("-c"),
-            octave_value(quote("-std=gnu++11")),
+            octave_value(quote(stdflag)),
             octave_value(dbg),
             octave_value(quote("-I" + incdir)),
             octave_value("-fPIC"),
@@ -1041,7 +1057,7 @@ namespace coder_compiler
             octave_value("-o"),
             octave_value(quote(obj)),
             octave_value("-c"),
-            octave_value(quote("-std=gnu++11")),
+            octave_value(quote(stdflag)),
             octave_value(dbg),
             octave_value(quote("-I" + incdir)),
             octave_value("-fPIC"),
