@@ -1,6 +1,16 @@
 #include  <bitset>
 #include  <memory>
 
+#include <octave/octave-config.h>
+#ifdef OCTAVE_EXPORT
+  #undef OCTAVE_EXPORT
+  #define OCTAVE_EXPORT
+#endif
+#ifdef OCTAVE_IMPORT
+  #undef OCTAVE_IMPORT
+  #define OCTAVE_IMPORT
+#endif
+
 #include <octave/defaults.h>
 #include <octave/error.h>
 #include <octave/file-ops.h>
@@ -25,6 +35,12 @@
   #define OCTAVE_RANGE ::Range
 #endif
 
+#if OCTAVE_MAJOR_VERSION < 10
+    #define LIST_LEN(list) list->length()
+#else
+    #define LIST_LEN(list) list->size()
+#endif
+
 namespace coder_compiler
 {
   namespace
@@ -343,7 +359,7 @@ namespace coder_compiler
       {
         bool takes_varargs = param_list->takes_varargs ();
 
-        int len = param_list->length ();
+        int len = LIST_LEN(param_list);
 
         if (len > 0 || takes_varargs)
           {
@@ -967,12 +983,14 @@ namespace coder_compiler
   void
   code_generator::visit_octave_user_function_header (octave_user_function& fcn)
   {
+#if OCTAVE_MAJOR_VERSION < 10
     octave::comment_list *leading_comment = fcn.leading_comment ();
 
     if (leading_comment)
       {
         //print_comment_list (leading_comment);
       }
+#endif    
 
     bool nested  = fcn.is_nested_function() ;
 
@@ -1015,7 +1033,7 @@ namespace coder_compiler
       {
         bool takes_varargs = fcn.takes_varargs ();
 
-        int len = param_list->length ();
+        int len = LIST_LEN(param_list);
 
         if (len > 0 || takes_varargs)
           {
@@ -1189,7 +1207,7 @@ namespace coder_compiler
       {
         bool takes_var_return = fcn.takes_var_return ();
 
-        int len = ret_list->length ();
+        int len = LIST_LEN(ret_list);
 
         os_src << "return make_return_list(output";
 
@@ -1878,6 +1896,8 @@ namespace coder_compiler
       os_src
         <<"Handle(";
 
+    bool is_resolved = true;
+
     auto idx = visit_dot_separated_fcn_handle (fh);
 
     if (! idx)
@@ -1889,7 +1909,9 @@ namespace coder_compiler
             if (! (symbol && symbol->file))
               symbol = scope->lookup_in_parent_scopes(fh.name(), symbol_type::ordinary);
 
-            if (symbol && symbol->file)
+            is_resolved = symbol && symbol->fcn.is_defined ();
+
+            if (is_resolved && symbol->file)
               {
                 os_src
                   << "&"
@@ -1902,7 +1924,7 @@ namespace coder_compiler
         os_src
           << mangle(fh.name());
 
-        if (! is_special_function && ! is_nested)
+        if (is_resolved && ! is_special_function && ! is_nested)
           os_src
             << "make";
       }
@@ -1974,7 +1996,7 @@ namespace coder_compiler
       if (same_type)
         os_src << "Ptr (";
 
-        op->accept (*this);
+      op->accept (*this);
 
       if (same_type)
         os_src << ")";
@@ -2021,7 +2043,7 @@ namespace coder_compiler
       if (same_type)
         os_src << "Ptr (";
 
-        op->accept (*this);
+      op->accept (*this);
 
       if (same_type)
         os_src << ")";
@@ -3150,6 +3172,10 @@ namespace coder_compiler
               {
                 os_src << "file_type::classdef";
               }
+            else if ( m_file->type == file_type::legacyclass)
+              {
+                os_src << "file_type::legacyclass";
+              }
           }
 
         os_src
