@@ -2,6 +2,16 @@
 #include <memory>
 #include "sys/stat.h"
 
+#include <octave/octave-config.h>
+#ifdef OCTAVE_EXPORT
+  #undef OCTAVE_EXPORT
+  #define OCTAVE_EXPORT
+#endif
+#ifdef OCTAVE_IMPORT
+  #undef OCTAVE_IMPORT
+  #define OCTAVE_IMPORT
+#endif
+
 #include <octave/builtin-defun-decls.h>
 #include <octave/dir-ops.h>
 #include <octave/file-ops.h>
@@ -13,6 +23,12 @@
 
 #include "semantic_analyser.h"
 
+#if OCTAVE_MAJOR_VERSION < 10
+    #define LIST_LEN(list) list->length()
+#else
+    #define LIST_LEN(list) list->size()
+#endif
+
 namespace coder_compiler
 {
   struct unwind
@@ -214,7 +230,7 @@ namespace coder_compiler
 
     if (lhs)
       {
-        int len = lhs->length ();
+        int len = LIST_LEN(lhs);
 
         if (len == 0 || len > 2)
           error ("invalid number of output arguments in for command");
@@ -872,7 +888,7 @@ namespace coder_compiler
 
         local_functions.clear();
 
-        if (current_file()->fcn.is_user_function())
+        if ((current_file()->type == file_type::m || current_file()->type == file_type::cmdline) && current_file()->fcn.is_user_function())
           {
             for (const auto& sub: current_file()->fcn.user_function_value()->subfunctions())
               {
